==> beast-privilege-api-3.0-GS-20250717.104339-8-sources.jar: com/thebeastshop/privilege/cond/FlowerPackageCond.java <==
package com.thebeastshop.privilege.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

public class FlowerPackageCond extends BaseQueryCond {
    private Long packageId;
    private List<String> packageCodes;
    private List<String> skuCodes;
    private List<String> nonSkuCodes;

    private Integer packageStatus;
    private List<Integer> categoryIds;
    private Date planedDeliveryDateStart;
    private Date planedDeliveryDateEnd;
    private Date expectReceiveDateStart;
    private Date expectReceiveDateEnd;
    private Integer cityId;
    private String channelCode;
    private Integer expressType;
    private String dispatchWarehouseCode;

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public List<String> getPackageCodes() {
        return packageCodes;
    }

    public void setPackageCodes(List<String> packageCodes) {
        this.packageCodes = packageCodes;
    }

    public List<String> getSkuCodes() {
        return skuCodes;
    }

    public void setSkuCodes(List<String> skuCodes) {
        this.skuCodes = skuCodes;
    }

    public List<String> getNonSkuCodes() {
        return nonSkuCodes;
    }

    public void setNonSkuCodes(List<String> nonSkuCodes) {
        this.nonSkuCodes = nonSkuCodes;
    }

    public Integer getPackageStatus() {
        return packageStatus;
    }

    public void setPackageStatus(Integer packageStatus) {
        this.packageStatus = packageStatus;
    }
    public List<Integer> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Integer> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public Date getPlanedDeliveryDateStart() {
        return planedDeliveryDateStart;
    }

    public void setPlanedDeliveryDateStart(Date planedDeliveryDateStart) {
        this.planedDeliveryDateStart = planedDeliveryDateStart;
    }

    public Date getPlanedDeliveryDateEnd() {
        return planedDeliveryDateEnd;
    }

    public void setPlanedDeliveryDateEnd(Date planedDeliveryDateEnd) {
        this.planedDeliveryDateEnd = planedDeliveryDateEnd;
    }

    public Date getExpectReceiveDateStart() {
        return expectReceiveDateStart;
    }

    public void setExpectReceiveDateStart(Date expectReceiveDateStart) {
        this.expectReceiveDateStart = expectReceiveDateStart;
    }

    public Date getExpectReceiveDateEnd() {
        return expectReceiveDateEnd;
    }

    public void setExpectReceiveDateEnd(Date expectReceiveDateEnd) {
        this.expectReceiveDateEnd = expectReceiveDateEnd;
    }

    public Integer getCityId() {
        return cityId;
    }

    public void setCityId(Integer cityId) {
        this.cityId = cityId;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getExpressType() {
        return expressType;
    }

    public void setExpressType(Integer expressType) {
        this.expressType = expressType;
    }

    public String getDispatchWarehouseCode() {
        return dispatchWarehouseCode;
    }

    public void setDispatchWarehouseCode(String dispatchWarehouseCode) {
        this.dispatchWarehouseCode = dispatchWarehouseCode;
    }

}

==> beast-privilege-api-3.0.2-GS-20250806.032603-15-sources.jar: com/thebeastshop/privilege/cond/FlowerPackageCond.java <==
package com.thebeastshop.privilege.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

public class FlowerPackageCond extends BaseQueryCond {
    private Long packageId;

    private List<Long> packageIds;
    private List<String> packageCodes;
    private List<String> skuCodes;
    private List<String> nonSkuCodes;

    private Integer packageStatus;
    private List<Integer> categoryIds;
    private Date planedDeliveryDateStart;
    private Date planedDeliveryDateEnd;
    private Date expectReceiveDateStart;
    private Date expectReceiveDateEnd;
    private Integer cityId;
    private String channelCode;
    private Integer expressType;
    private String dispatchWarehouseCode;

    private List<String> dispatchWarehouseCodes;

    private Integer isCarQuery;

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public List<Long> getPackageIds() {
        return packageIds;
    }

    public void setPackageIds(List<Long> packageIds) {
        this.packageIds = packageIds;
    }

    public List<String> getPackageCodes() {
        return packageCodes;
    }

    public void setPackageCodes(List<String> packageCodes) {
        this.packageCodes = packageCodes;
    }

    public List<String> getSkuCodes() {
        return skuCodes;
    }

    public void setSkuCodes(List<String> skuCodes) {
        this.skuCodes = skuCodes;
    }

    public List<String> getNonSkuCodes() {
        return nonSkuCodes;
    }

    public void setNonSkuCodes(List<String> nonSkuCodes) {
        this.nonSkuCodes = nonSkuCodes;
    }

    public Integer getPackageStatus() {
        return packageStatus;
    }

    public void setPackageStatus(Integer packageStatus) {
        this.packageStatus = packageStatus;
    }
    public List<Integer> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Integer> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public Date getPlanedDeliveryDateStart() {
        return planedDeliveryDateStart;
    }

    public void setPlanedDeliveryDateStart(Date planedDeliveryDateStart) {
        this.planedDeliveryDateStart = planedDeliveryDateStart;
    }

    public Date getPlanedDeliveryDateEnd() {
        return planedDeliveryDateEnd;
    }

    public void setPlanedDeliveryDateEnd(Date planedDeliveryDateEnd) {
        this.planedDeliveryDateEnd = planedDeliveryDateEnd;
    }

    public Date getExpectReceiveDateStart() {
        return expectReceiveDateStart;
    }

    public void setExpectReceiveDateStart(Date expectReceiveDateStart) {
        this.expectReceiveDateStart = expectReceiveDateStart;
    }

    public Date getExpectReceiveDateEnd() {
        return expectReceiveDateEnd;
    }

    public void setExpectReceiveDateEnd(Date expectReceiveDateEnd) {
        this.expectReceiveDateEnd = expectReceiveDateEnd;
    }

    public Integer getCityId() {
        return cityId;
    }

    public void setCityId(Integer cityId) {
        this.cityId = cityId;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getExpressType() {
        return expressType;
    }

    public void setExpressType(Integer expressType) {
        this.expressType = expressType;
    }

    public String getDispatchWarehouseCode() {
        return dispatchWarehouseCode;
    }

    public void setDispatchWarehouseCode(String dispatchWarehouseCode) {
        this.dispatchWarehouseCode = dispatchWarehouseCode;
    }

    public List<String> getDispatchWarehouseCodes() {
        return dispatchWarehouseCodes;
    }

    public void setDispatchWarehouseCodes(List<String> dispatchWarehouseCodes) {
        this.dispatchWarehouseCodes = dispatchWarehouseCodes;
    }

    public Integer getIsCarQuery() {
        return isCarQuery;
    }

    public void setIsCarQuery(Integer isCarQuery) {
        this.isCarQuery = isCarQuery;
    }


}
